@@ -980,10 +980,10 @@ set_attachments_to_cal_component (EGwItem *item,
 static void
 set_default_alarms (ECalComponent *comp)
 {
+	GSettings *settings;
+	settings = g_settings_new ("org.gnome.evolution.calendar");
 
-	GConfClient *gconf = gconf_client_get_default ();
-
-	if (gconf_client_get_bool (gconf, CALENDAR_CONFIG_DEFAULT_REMINDER, NULL)) {
+	if (g_settings_get_boolean (settings, "use-default-reminder")) {
 
 			ECalComponentAlarm *acomp;
 			gint interval;
@@ -995,8 +995,8 @@ set_default_alarms (ECalComponent *comp)
 			} duration;
 			ECalComponentAlarmTrigger trigger;
 
-			interval = gconf_client_get_int (gconf, CALENDAR_CONFIG_DEFAULT_REMINDER_INTERVAL, NULL);
-			units = gconf_client_get_string (gconf, CALENDAR_CONFIG_DEFAULT_REMINDER_UNITS, NULL);
+			interval = g_settings_get_int (settings, "default-reminder-interval");
+			units = g_settings_get_string (settings, "default-reminder-units");
 
 			if (units == NULL)
 				duration = MINUTES;
@@ -1030,7 +1030,7 @@ set_default_alarms (ECalComponent *comp)
 				break;
 			default:
 				e_cal_component_alarm_free (acomp);
-				g_object_unref (gconf);
+				g_object_unref (settings);
 				return;
 			}
 
@@ -1039,7 +1039,7 @@ set_default_alarms (ECalComponent *comp)
 
 			e_cal_component_alarm_free (acomp);
 		}
-		g_object_unref (gconf);
+		g_object_unref (settings);
 }
 
 static gchar *
