@@ -34,7 +34,7 @@
 #include "e-util/e-alert-dialog.h"
 #include <libecal/e-cal-client.h>
 #include <shell/e-shell.h>
-#include <e-util/e-account-utils.h>
+#include <libemail-utils/e-account-utils.h>
 
 /*stores some info about all currently existing groupwise accounts
   list of GwAccountInfo structures */
