@@ -21,6 +21,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -28,7 +32,9 @@
 #include <stdio.h>
 
 #include <glib.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
+
+#include <e-util/e-util.h>
 
 #include "mail-send-options.h"
 
@@ -217,8 +223,8 @@ gw_ui_composer_actions (GtkUIManager *manager,
 	editor = GTKHTML_EDITOR (composer);
 
 	/* Add actions to the "composer" action group. */
-	gtk_action_group_add_actions (
-		gtkhtml_editor_get_action_group (editor, "composer"),
+	e_action_group_add_actions_localized (
+		gtkhtml_editor_get_action_group (editor, "composer"), GETTEXT_PACKAGE,
 		entries, G_N_ELEMENTS (entries), composer);
 
 	headers = e_msg_composer_get_header_table (composer);
