@@ -29,16 +29,16 @@
 #include <glib/gi18n-lib.h>
 
 #include <libedataserverui/e-passwords.h>
+#include <libemail-utils/e-account-utils.h>
 #include <mail/em-folder-tree.h>
 #include <mail/e-mail-backend.h>
+#include <mail/e-mail-ui-session.h>
 #include <mail/em-folder-selector.h>
 #include <mail/em-account-editor.h>
-#include <mail/mail-ops.h>
 #include <libedataserver/e-account.h>
 #include <e-util/e-util.h>
 #include <e-util/e-alert-dialog.h>
 #include <e-util/e-icon-factory.h>
-#include <e-util/e-account-utils.h>
 #include <shell/e-shell-view.h>
 #include <calendar/gui/itip-utils.h>
 
@@ -441,7 +441,7 @@ proxy_login_add_new_store (CamelStore *store,
 
 	store->flags |= CAMEL_STORE_PROXY;
 
-	account_store = e_mail_session_get_account_store (session);
+	account_store = e_mail_ui_session_get_account_store (E_MAIL_UI_SESSION (session));
 	e_mail_account_store_add_service (account_store, CAMEL_SERVICE (store));
 }
 
