@@ -30,15 +30,14 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
 #include <e-util/e-config.h>
-#include <e-util/e-account-utils.h>
+#include <libemail-utils/e-account-utils.h>
+#include <libemail-utils/mail-mt.h>
 #include <mail/e-mail-backend.h>
-#include <mail/e-mail-folder-utils.h>
 #include <mail/em-config.h>
 #include <mail/em-folder-properties.h>
 #include <mail/em-folder-tree.h>
 #include <mail/em-folder-tree-model.h>
 #include <mail/em-folder-selector.h>
-#include <mail/mail-mt.h>
 #include <mail/mail-vfolder.h>
 #include <mail/em-utils.h>
 #include <mail/em-vfolder-rule.h>
